==> rnp_0.14.0.orig.tar.gz: rnp-0.14.0/cmake/info.cmake <==
# Copyright (c) 2018 Ribose Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS
# BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

# this file contains things that are likely to change occasionally
set(PACKAGE_VENDOR "Ribose Inc.")
set(PACKAGE_URL "https://github.com/rnpgp/rnp")

set(PACKAGING_EMAIL "Ribose Inc. <packaging@ribose.com>")
set(BUGREPORT_EMAIL "${PACKAGING_EMAIL}")

set(PACKAGE_DESCRIPTION [=[
A set of OpenPGP tools for encrypting, decrypting, signing, and \
verifying files.
]=]
)
set(PACKAGE_DESCRIPTION_SHORT "Freely licensed PGP implementation")
set(PACKAGE_LICENSE "BSD")

set(RPM_RELEASE_NUM 1)
set(DEB_RELEASE_NUM 1)

==> rnp_0.15.2.orig.tar.gz: rnp-0.15.2/cmake/info.cmake <==
# Copyright (c) 2018 Ribose Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS
# BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

# this file contains things that are likely to change occasionally
set(PACKAGE_VENDOR "Ribose Inc.")
set(PACKAGE_URL "https://github.com/rnpgp/rnp")

set(PACKAGING_EMAIL "Ribose Inc. <rnpgp@ribose.com>")
set(BUGREPORT_EMAIL "${PACKAGING_EMAIL}")

set(PACKAGE_DESCRIPTION [=[
A set of OpenPGP tools for encrypting, decrypting, signing, and \
verifying files.
]=]
)
set(PACKAGE_DESCRIPTION_SHORT "Freely-licensed OpenPGP library and command-line tools")
set(PACKAGE_LICENSE "BSD")

set(RPM_RELEASE_NUM 1)
set(DEB_RELEASE_NUM 1)
